ReceiptData class
Constructors
-
ReceiptData({String? businessName, String? header, String? address, String? tell, String? whatsapp, String? instagram, String? transactionDate, String? transactionTime, String? transactionID, String? transactionReference, List<
ReceiptItem> ? items, String? currencyCode, double? withdrawalAmount, double? totalValue, double? totalDiscount, double? cashbackAmount, double? tipAmount, double? totalTax, bool? taxInclusive, double? totalDue, double? amountTendered, double? amountChange, String? customerName, bool? displayCustomer, String? sellerName, bool? displaySeller, bool? isRefund = false}) -
ReceiptData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address ↔ String?
-
getter/setter pair
- amountChange ↔ double?
-
getter/setter pair
- amountTendered ↔ double?
-
getter/setter pair
- businessName ↔ String?
-
getter/setter pair
- cashbackAmount ↔ double?
-
getter/setter pair
- currencyCode ↔ String?
-
getter/setter pair
- customerName ↔ String?
-
getter/setter pair
- displayCustomer ↔ bool?
-
getter/setter pair
- displaySeller ↔ bool?
-
getter/setter pair
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- header ↔ String?
-
getter/setter pair
- instagram ↔ String?
-
getter/setter pair
- isRefund ↔ bool?
-
getter/setter pair
-
items
↔ List<
ReceiptItem> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sellerName ↔ String?
-
getter/setter pair
- taxInclusive ↔ bool?
-
getter/setter pair
- tell ↔ String?
-
getter/setter pair
- tipAmount ↔ double?
-
getter/setter pair
- totalDiscount ↔ double?
-
getter/setter pair
- totalDue ↔ double?
-
getter/setter pair
- totalTax ↔ double?
-
getter/setter pair
- totalValue ↔ double?
-
getter/setter pair
- transactionDate ↔ String?
-
getter/setter pair
- transactionID ↔ String?
-
getter/setter pair
- transactionReference ↔ String?
-
getter/setter pair
- transactionTime ↔ String?
-
getter/setter pair
- whatsapp ↔ String?
-
getter/setter pair
- withdrawalAmount ↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited